<?php

namespace apexl\Io\modules\component\entities;

use JsonSerializable;

final readonly class ComponentProperty implements JsonSerializable
{
    public function __construct(
        public string $name,
        public mixed $value,
    ) {}

    public function jsonSerialize(): mixed
    {
        return $this->value;
    }
}
