<?php

namespace apexl\Io\modules\component\Collections;

use apexl\Io\modules\component\entities\componentEntity;
use Arrayy\Collection\AbstractCollection;

final class ComponentCollection extends AbstractCollection
{
    public function getType(): string
    {
        return componentEntity::class;
    }
}
